From b1c6ea23c4e7f1939dcade2b86c31c864a2e4e6b Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Sun, 6 Nov 2011 02:23:21 -0600
Subject: Additional kde to tde renaming

---
 ChangeLog                           |  4 ++--
 FAQ                                 |  4 ++--
 acinclude.m4                        | 26 +++++++++++++-------------
 doc/en/index.docbook                |  4 ++--
 smb4k/Makefile.am                   |  2 +-
 smb4k/core/smb4kfileio.cpp          | 16 ++++++++--------
 smb4k/core/smb4kpasswordhandler.cpp |  2 +-
 7 files changed, 29 insertions(+), 29 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 65945b7..0c2ba6e 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -787,9 +787,9 @@ Smb4K 0.6.3:
   + disable the OK button of the mount dialog if the input line is empty.
 
 Smb4K 0.6.2:
-- Fixed security issue: When ignoring the kdesu dialog a copy of the
+- Fixed security issue: When ignoring the tdesu dialog a copy of the
   super.tab file was left under /tmp.
-- Error messages won't pop up anymore when ignoring the kdesu dialog. The
+- Error messages won't pop up anymore when ignoring the tdesu dialog. The
   reporting of unknown errors has been disabled in
   Smb4KFileIO::slotReceivedStderr() (closes #4309).
 - Fixed reading of authentication data.
diff --git a/FAQ b/FAQ
index 009c00b..c67678b 100644
--- a/FAQ
+++ b/FAQ
@@ -272,13 +272,13 @@ A:  First of all, check that you haven't opened the mount point or one of its
     haven't opened any file belonging to the share. If neither is the case,
     you might have encountered a problem, that is known but not related to
     Smb4K. It seems, that under certain circumstances (that we could not
-    figure out exactly) kdeinit (KDE < 3.4) background processes access files
+    figure out exactly) tdeinit (KDE < 3.4) background processes access files
     and/or directories of the share and keep them open. Unmounting is not
     possible unless you send
 
     $ kill -HUP <PID>
 
-    to each kdeinit instance that has access to the share or its files.
+    to each tdeinit instance that has access to the share or its files.
 
     Alternatively, you can force the unmounting of the share. Highlight the
     share and use the Shares->Force Unmounting menu item or press Ctrl+F.
diff --git a/acinclude.m4 b/acinclude.m4
index 3eb4fd0..29715e3 100644
--- a/acinclude.m4
+++ b/acinclude.m4
@@ -371,7 +371,7 @@ AC_DEFUN([KDE_1_CHECK_PATHS],
   fi
 
 AC_MSG_CHECKING([for KDE libraries installed])
-ac_link='$LIBTOOL_SHELL --silent --mode=link ${CXX-g++} -o conftest $CXXFLAGS $all_includes $CPPFLAGS $LDFLAGS $all_libraries conftest.$ac_ext $LIBS -lkdecore $LIBQT $KDE_TEST_RPATH 1>&5'
+ac_link='$LIBTOOL_SHELL --silent --mode=link ${CXX-g++} -o conftest $CXXFLAGS $all_includes $CPPFLAGS $LDFLAGS $all_libraries conftest.$ac_ext $LIBS -ltdecore $LIBQT $KDE_TEST_RPATH 1>&5'
 
 if AC_TRY_EVAL(ac_link) && test -s conftest; then
   AC_MSG_RESULT(yes)
@@ -710,7 +710,7 @@ AC_SUBST(kde_templatesdir)
 AC_SUBST(kde_servicesdir)
 AC_SUBST(kde_servicetypesdir)
 AC_SUBST(kde_moduledir)
-AC_SUBST(kdeinitdir, '$(kde_moduledir)')
+AC_SUBST(tdeinitdir, '$(kde_moduledir)')
 AC_SUBST(kde_styledir)
 AC_SUBST(kde_widgetdir)
 if test "$kde_qtver" = 1; then
@@ -2064,12 +2064,12 @@ AC_DEFUN([KDE_CREATE_LIBS_ALIASES],
 
 if test $kde_qtver = 3; then
    case $host in 
-               *cygwin*) lib_kded="-lkdeinit_kded" ;;
+               *cygwin*) lib_kded="-ltdeinit_kded" ;;
                *) lib_kded="" ;;
        esac
    AC_SUBST(LIB_KDED, $lib_kded)
-   AC_SUBST(LIB_KDECORE, "-lkdecore")
-   AC_SUBST(LIB_KDEUI, "-lkdeui")
+   AC_SUBST(LIB_KDECORE, "-ltdecore")
+   AC_SUBST(LIB_KDEUI, "-ltdeui")
    AC_SUBST(LIB_KIO, "-lkio")
    AC_SUBST(LIB_KJS, "-lkjs")
    AC_SUBST(LIB_SMB, "-lsmb")
@@ -2078,9 +2078,9 @@ if test $kde_qtver = 3; then
    AC_SUBST(LIB_KHTML, "-lkhtml")
    AC_SUBST(LIB_KSPELL, "-lkspell")
    AC_SUBST(LIB_KPARTS, "-lkparts")
-   AC_SUBST(LIB_KDEPRINT, "-lkdeprint")
+   AC_SUBST(LIB_KDEPRINT, "-ltdeprint")
    AC_SUBST(LIB_KUTILS, "-lkutils")
-   AC_SUBST(LIB_KDEPIM, "-lkdepim")
+   AC_SUBST(LIB_KDEPIM, "-ltdepim")
    AC_SUBST(LIB_KIMPROXY, "-lkimproxy")
    AC_SUBST(LIB_KNEWSTUFF, "-lknewstuff")
    AC_SUBST(LIB_KDNSSD, "-lkdnssd")
@@ -2089,8 +2089,8 @@ if test $kde_qtver = 3; then
    AC_SUBST(LIB_KSYCOCA, "-lkio")
    AC_SUBST(LIB_KFILE, "-lkio")
 elif test $kde_qtver = 2; then
-   AC_SUBST(LIB_KDECORE, "-lkdecore")
-   AC_SUBST(LIB_KDEUI, "-lkdeui")
+   AC_SUBST(LIB_KDECORE, "-ltdecore")
+   AC_SUBST(LIB_KDEUI, "-ltdeui")
    AC_SUBST(LIB_KIO, "-lkio")
    AC_SUBST(LIB_KSYCOCA, "-lksycoca")
    AC_SUBST(LIB_SMB, "-lsmb")
@@ -2099,10 +2099,10 @@ elif test $kde_qtver = 2; then
    AC_SUBST(LIB_KHTML, "-lkhtml")
    AC_SUBST(LIB_KSPELL, "-lkspell")
    AC_SUBST(LIB_KPARTS, "-lkparts")
-   AC_SUBST(LIB_KDEPRINT, "-lkdeprint")
+   AC_SUBST(LIB_KDEPRINT, "-ltdeprint")
 else
-   AC_SUBST(LIB_KDECORE, "-lkdecore -lXext $(LIB_QT)")
-   AC_SUBST(LIB_KDEUI, "-lkdeui $(LIB_KDECORE)")
+   AC_SUBST(LIB_KDECORE, "-ltdecore -lXext $(LIB_QT)")
+   AC_SUBST(LIB_KDEUI, "-ltdeui $(LIB_KDECORE)")
    AC_SUBST(LIB_KFM, "-lkfm $(LIB_KDECORE)")
    AC_SUBST(LIB_KFILE, "-lkfile $(LIB_KFM) $(LIB_KDEUI)")
    AC_SUBST(LIB_KAB, "-lkab $(LIB_KIMGIO) $(LIB_KDECORE)")
@@ -2489,7 +2489,7 @@ if eval "test \"`echo $ac_cv_lib_gif`\" = yes"; then
   AC_MSG_RESULT(yes)
   AC_DEFINE_UNQUOTED(HAVE_LIBGIF, 1, [Define if you have libgif])
 else
-  AC_MSG_ERROR(You need giflib30. Please install the kdesupport package)
+  AC_MSG_ERROR(You need giflib30. Please install the tdesupport package)
 fi
 ])
 
diff --git a/doc/en/index.docbook b/doc/en/index.docbook
index d29f63d..95612b5 100644
--- a/doc/en/index.docbook
+++ b/doc/en/index.docbook
@@ -5114,9 +5114,9 @@ Refer to the mount.cifs(8) manual page (e.g.man mount.cifs)</errortext></screen>
 <listitem id="trouble_shooting_unmounting_resource_busy">
 <para><emphasis role="bold">Problem:</emphasis> Unmounting a share fails with the following error message:</para>
 <para><screen><errortext>Could not unmount &#060;PATH&#062;: Device or resource busy</errortext></screen></para>
-<para><emphasis role="bold">Solution:</emphasis> First of all, check that you do not access any directory or file of the share with any program. If this isn't the case, you might have encountered a problem, that is known but not related to &smb4k;. It seems that under certain circumstances (that we could not figure out exactly) kdeinit background processes access files and/or directories of the share and keep them open (&kde; &#060; 3.4). Unmounting is not possible unless you send
+<para><emphasis role="bold">Solution:</emphasis> First of all, check that you do not access any directory or file of the share with any program. If this isn't the case, you might have encountered a problem, that is known but not related to &smb4k;. It seems that under certain circumstances (that we could not figure out exactly) tdeinit background processes access files and/or directories of the share and keep them open (&kde; &#060; 3.4). Unmounting is not possible unless you send
 <screen><prompt>$</prompt> <userinput><command>kill</command> -HUP PID</userinput></screen>
-to each kdeinit instance that has access to the share or its files. Replace PID by the pid of the kdeinit instance. You can find it out by using e. g. &ksysguard;.</para>
+to each tdeinit instance that has access to the share or its files. Replace PID by the pid of the tdeinit instance. You can find it out by using e. g. &ksysguard;.</para>
 <para>Alternatively, you can force the unmounting of the share (not recommended). Highlight the share and use the <menuchoice><guimenu>Shares</guimenu><guimenuitem>Force Unmounting</guimenuitem></menuchoice> menu item or press <keycombo action="simul">&Ctrl;<keycap>F</keycap></keycombo>.</para>
 <para><emphasis role="bold">Note:</emphasis> Linux and similar operating systems</para>
 </listitem>
diff --git a/smb4k/Makefile.am b/smb4k/Makefile.am
index 80422b9..39c9129 100644
--- a/smb4k/Makefile.am
+++ b/smb4k/Makefile.am
@@ -9,7 +9,7 @@ bin_PROGRAMS = smb4k
 smb4k_SOURCES = main.cpp smb4k.cpp smb4ksystemtray.cpp
 smb4k_LDADD = $(top_builddir)/smb4k/core/libsmb4kcore.la \
 	$(top_builddir)/smb4k/dialogs/libsmb4kdialogs.la $(LIB_KDECORE) $(LIB_KDEUI) $(LIB_KFILE) $(LIB_KPARTS) $(LIB_QT)
-smb4k_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+smb4k_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 
 KDE_ICON = smb4k
diff --git a/smb4k/core/smb4kpasswordhandler.cpp b/smb4k/core/smb4kpasswordhandler.cpp
index e3624ee..7d0eb5c 100644
--- a/smb4k/core/smb4kpasswordhandler.cpp
+++ b/smb4k/core/smb4kpasswordhandler.cpp
@@ -111,7 +111,7 @@ void Smb4KPasswordHandler::open_close_wallet()
       // error handling here.
       if ( kapp )
       {
-        (void) kapp->kdeinitExec( "kwalletmanager" );
+        (void) kapp->tdeinitExec( "kwalletmanager" );
       }
       else
       {
diff --git a/smb4k/core/smb4kfileio.cpp b/smb4k/core/smb4kfileio.cpp
index 9b42709..1a365a3 100644
--- a/smb4k/core/smb4kfileio.cpp
+++ b/smb4k/core/smb4kfileio.cpp
@@ -375,11 +375,11 @@ bool Smb4KFileIO::writeSudoers( Smb4KFileIO::Operation operation )
       {
         // The user does not have enough access rights to perform
         // the modification of the sudoers file. So, we need to use
         // kdesu to get the contents of the file.
 
         // Compose the command:
         TQString command;
-        command.append( "kdesu -t -c \"smb4k_cat " );
+        command.append( "tdesu -t -c \"smb4k_cat " );
         command.append( canonical_path+"\"" );
         command.append( " ; sleep 2" );
 
@@ -728,11 +728,11 @@ bool Smb4KFileIO::writeSuperTab( Smb4KFileIO::Operation operation )
       {
         // The user does not have enough access rights to perform
         // the modification of the sudoers file. So, we need to use
         // kdesu to get the contents of the file.
 
         // Compose the command:
         TQString command;
-        command.append( "kdesu -t -c \"smb4k_cat " );
+        command.append( "tdesu -t -c \"smb4k_cat " );
         command.append( canonical_path+"\"" );
         command.append( " ; sleep 2" );
 
@@ -1184,7 +1184,7 @@ void Smb4KFileIO::processSudoers()
 {
   // If the output buffer is empty, we stop, because
   // that most likely means, the user cancelled the
-  // kdesu dialog.
+  // tdesu dialog.
   if ( m_buffer.stripWhiteSpace().isEmpty() )
   {
     emit failed();
@@ -1411,7 +1411,7 @@ void Smb4KFileIO::processSudoers()
 
     // Assemble the command.
     TQString command;
-    command.append( "kdesu -n -c \"smb4k_mv "+owner+":"+group+" "+perms+" " );
+    command.append( "tdesu -n -c \"smb4k_mv "+owner+":"+group+" "+perms+" " );
     command.append( temp_file_name+" " );
     command.append( canonical_path+"\" ; " );
     command.append( "rm -f "+temp_file_name );
@@ -1436,7 +1436,7 @@ void Smb4KFileIO::processSuperTab()
 {
   // If the output buffer is empty, we stop, because
   // that most likely means, the user cancelled the
-  // kdesu dialog.
+  // tdesu dialog.
   if ( m_buffer.stripWhiteSpace().isEmpty() )
   {
     emit failed();
@@ -1674,7 +1674,7 @@ void Smb4KFileIO::processSuperTab()
 
     // Assemble the command.
     TQString command;
-    command.append( "kdesu -n -c \"smb4k_mv "+owner+":"+group+" "+perms+" " );
+    command.append( "tdesu -n -c \"smb4k_mv "+owner+":"+group+" "+perms+" " );
     command.append( temp_file_name+" " );
     command.append( canonical_path+"\" ; " );
     command.append( "rm -f "+temp_file_name );
@@ -375,11 +375,11 @@ bool Smb4KFileIO::writeSudoers( Smb4KFileIO::Operation operation )
         // The user does not have enough access rights to perform
         // the modification of the sudoers file. So, we need to use
-        // kdesu to get the contents of the file.
+        // tdesu to get the contents of the file.
 
         // Compose the command:
@@ -728,11 +728,11 @@ bool Smb4KFileIO::writeSuperTab( Smb4KFileIO::Operation operation )
         // The user does not have enough access rights to perform
         // the modification of the sudoers file. So, we need to use
-        // kdesu to get the contents of the file.
+        // tdesu to get the contents of the file.
 
         // Compose the command:
-- 
cgit v1.2.3

